@@ -123,8 +123,6 @@ Q_SIGNALS:
     void plasmaWindowManagementInitialized();
 };
 
-void authenticate();
-
 bool isStreamingEnabled();
 bool isStreamingAvailable();
 
@@ -139,9 +137,11 @@ void requestPointerButtonPress(quint32 linuxButton);
 void requestPointerButtonRelease(quint32 linuxButton);
 void requestPointerMotion(const QSizeF &delta);
 void requestPointerMotionAbsolute(const QPointF &pos);
+void requestPointerAxis(qreal x, qreal y);
 void requestPointerAxisDiscrete(Qt::Orientation axis, qreal delta);
 
 void requestKeyboardKeycode(int keycode, bool state);
+void requestKeyboardKeysym(int keysym, bool state);
 
 void requestTouchDown(quint32 touchPoint, const QPointF &pos);
 void requestTouchMotion(quint32 touchPoint, const QPointF &pos);
